@@ -78,8 +78,9 @@ class dbg():
 
 class print_dbg():
 
-    def __new__(cls, *args, **kwargs):
-        print(args[0]) if dbg.get_module(args[1]) else None
+    def __new__(cls, text, module):
+        cls.print_dbg(cls, text, module)
+        # super(print_dbg, cls).__new__(cls, *args, **kwargs)
 
     def __init__(self):
         super(print_dbg, self).__init__()
@@ -89,3 +90,6 @@ class print_dbg():
 
     def __str__(self):
         super(print_dbg, self).__str__()
+
+    def print_dbg(cls, text, module):
+        print(text) if dbg.get_module(module) else None
